@@ -49,6 +49,8 @@
 #define DEFAULT_IMAGES_LOCATION DATADIR "/pixmaps/backgrounds"
 #define IMAGE_LOAD_TIMEOUT 10000
 
+static GMainLoop   *main_loop = NULL;
+
 static GdkWindow   *screenhack_window     = NULL;
 static guint        screenhack_timeout_id = 0;
 static int          window_width          = 400;
@@ -484,6 +486,12 @@ scale_pixbuf (GdkPixbuf *pixbuf,
         pw = gdk_pixbuf_get_width (pixbuf);
         ph = gdk_pixbuf_get_height (pixbuf);
 
+        /* If the image is less than 256 wide or high then it
+           is probably a thumbnail and we should ignore it */
+        if (pw < 256 || ph < 256) {
+                return NULL;
+        }
+
         /* Determine which dimension requires the smallest scale. */
         scale_factor_x = (float) max_width / (float) pw;
         scale_factor_y = (float) max_height / (float) ph;
@@ -603,8 +611,8 @@ get_pixbuf_from_location (const char *location)
 
 static GdkPixbuf *
 get_pixbuf (const char *location,
-            int   width,
-            int   height)
+            int         width,
+            int         height)
 {
         GdkPixbuf *pixbuf;
         GdkPixbuf *scaled = NULL;
@@ -775,7 +783,6 @@ screenhack_destroy (void)
         }
         g_async_queue_unref (results_q);
 
-
 }
 
 static gboolean
@@ -830,6 +837,7 @@ do_event (GdkEvent *event)
         case GDK_NOTHING:
                 break;
         case GDK_DELETE:
+                g_main_loop_quit (main_loop);
                 break;
         case GDK_DESTROY:
                 break;
@@ -847,7 +855,6 @@ do_event (GdkEvent *event)
 int
 main (int argc, char **argv)
 {
-        GMainLoop *main_loop = NULL;
         GError    *error;
         gboolean   ret;
 
