@@ -28,6 +28,7 @@
 #include <sys/time.h>
 #include <sys/types.h>
 #include <sys/wait.h>
+#include <unistd.h>
 
 #include <glib/gi18n.h>
 #include <gdk/gdkx.h>
@@ -40,6 +41,9 @@
 
 
 /* Profiling stuff adapted from gtkfilechooserdefault */
+/* To use run:
+ *  strace -ttt -f -o logfile.txt ./gnome-screensaver-dialog
+ */
 
 #undef PROFILE_LOCK_DIALOG
 #ifdef PROFILE_LOCK_DIALOG
@@ -61,20 +65,18 @@ _gs_lock_plug_profile_log (const char *func,
                            const char *msg1,
                            const char *msg2)
 {
-        char    *str;
-        GTimeVal now;
+        char *str;
 
         if (indent < 0)
                 profile_add_indent (indent);
 
-        g_get_current_time (&now);
-
         if (profile_indent == 0)
-                str = g_strdup_printf ("MARK %ld.%6.6ld: %s: %s %s %s", now.tv_sec, now.tv_usec, G_STRLOC, func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+                str = g_strdup_printf ("MARK: %s: %s %s %s", G_STRLOC, func, msg1 ? msg1 : "", msg2 ? msg2 : "");
         else
-                str = g_strdup_printf ("MARK %ld.%6.6ld: %s: %*c %s %s %s", now.tv_sec, now.tv_usec, G_STRLOC, profile_indent - 1, ' ', func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+                str = g_strdup_printf ("MARK: %s: %*c %s %s %s", G_STRLOC, profile_indent - 1, ' ', func, msg1 ? msg1 : "", msg2 ? msg2 : "");
+
+        access (str, F_OK);
 
-        fprintf (stderr, "%s\n", str);
         g_free (str);
 
         if (indent > 0)
@@ -91,10 +93,11 @@ _gs_lock_plug_profile_log (const char *func,
 #endif
 
 
-static gboolean verbose       = FALSE;
-static gboolean show_version  = FALSE;
-static gboolean enable_logout = FALSE;
-static gboolean enable_switch = FALSE;
+static gboolean verbose        = FALSE;
+static gboolean show_version   = FALSE;
+static gboolean enable_logout  = FALSE;
+static gboolean enable_switch  = FALSE;
+static char    *logout_command = NULL;
 
 static GOptionEntry entries [] = {
         { "verbose", 0, 0, G_OPTION_ARG_NONE, &verbose,
@@ -103,6 +106,8 @@ static GOptionEntry entries [] = {
           N_("Version of this application"), NULL },
         { "enable-logout", 0, 0, G_OPTION_ARG_NONE, &enable_logout,
           N_("Show the logout button"), NULL },
+        { "logout-command", 0, 0, G_OPTION_ARG_STRING, &logout_command,
+          N_("Command to invoke from the logout button"), NULL },
         { "enable-switch", 0, 0, G_OPTION_ARG_NONE, &enable_switch,
           N_("Show the switch user button"), NULL },
         { NULL }
@@ -185,6 +190,10 @@ popup_dialog_idle (void)
                 g_object_set (widget, "logout-enabled", TRUE, NULL);
         }
 
+        if (logout_command) {
+                g_object_set (widget, "logout-command", logout_command, NULL);
+        }
+
         if (enable_switch) {
                 g_object_set (widget, "switch-enabled", TRUE, NULL);
         }
