@@ -34,6 +34,7 @@
 #include <dbus/dbus-glib-lowlevel.h>
 
 #include "gs-listener-dbus.h"
+#include "gs-marshal.h"
 
 /* this is for dbus < 0.3 */
 #if ((DBUS_VERSION_MAJOR == 0) && (DBUS_VERSION_MINOR < 30))
@@ -66,6 +67,8 @@ struct GSListenerPrivate
         guint           active : 1;
         guint           throttle_enabled : 1;
         GHashTable     *inhibitors;
+
+        time_t          idle_start;
 };
 
 enum {
@@ -192,17 +195,30 @@ listener_check_activation (GSListener *listener)
         }
 }
 
-void
+gboolean
 gs_listener_set_active (GSListener *listener,
                         gboolean    active)
 {
-        g_return_if_fail (GS_IS_LISTENER (listener));
+        gboolean res;
+
+        g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
 
         if (listener->priv->active != active) {
 
-                listener->priv->active = active;
+                res = FALSE;
+                g_signal_emit (listener, signals [ACTIVE_CHANGED], 0, active, &res);
+                if (! res) {
+                        /* if the signal is not handled then we haven't changed state */
 
-                g_signal_emit (listener, signals [ACTIVE_CHANGED], 0, active);
+                        /* clear the idle state */
+                        if (active) {
+                                gs_listener_set_idle (listener, FALSE);
+                        }
+
+                        return FALSE;
+                }
+
+                listener->priv->active = active;
                 gs_listener_send_signal_active_changed (listener);
 
                 if (! active) {
@@ -210,8 +226,11 @@ gs_listener_set_active (GSListener *listener,
                         gs_listener_set_throttle_enabled (listener, FALSE);
                         /* if we are deactivating then reset the idle */
                         listener->priv->idle = active;
+                        listener->priv->idle_start = 0;
                 }
         }
+
+        return TRUE;
 }
 
 gboolean
@@ -220,8 +239,10 @@ gs_listener_set_idle (GSListener *listener,
 {
         g_return_val_if_fail (GS_IS_LISTENER (listener), FALSE);
 
-        if (listener->priv->idle == idle)
+        if (listener->priv->idle == idle) {
+                g_warning ("Trying to set idle when already idle");
                 return FALSE;
+        }
 
         if (idle) {
                 guint n_inhibitors = 0;
@@ -233,6 +254,10 @@ gs_listener_set_idle (GSListener *listener,
                 if (n_inhibitors != 0) {
                         return FALSE;
                 }
+
+                listener->priv->idle_start = time (NULL);
+        } else {
+                listener->priv->idle_start = 0;
         }
 
         listener->priv->idle = idle;
@@ -556,6 +581,48 @@ listener_get_property (GSListener     *listener,
         return DBUS_HANDLER_RESULT_HANDLED;
 }
 
+static DBusHandlerResult
+listener_get_idle_time (GSListener     *listener,
+                        DBusConnection *connection,
+                        DBusMessage    *message)
+{
+        const char     *path;
+        DBusMessageIter iter;
+        DBusMessage    *reply;
+        dbus_uint32_t    secs;
+
+        path = dbus_message_get_path (message);
+
+        reply = dbus_message_new_method_return (message);
+
+        dbus_message_iter_init_append (reply, &iter);
+
+        if (reply == NULL)
+                g_error ("No memory");
+
+        if (listener->priv->idle) {
+                time_t now = time (NULL);
+
+                if (now < listener->priv->idle_start) {
+                        /* should't happen */
+                        g_warning ("Idle start time is in the future");
+                        secs = 0;
+                } else {
+                        secs = listener->priv->idle_start - now;
+                }
+        } else {
+                secs = 0;
+        }
+        dbus_message_iter_append_basic (&iter, DBUS_TYPE_UINT32, &secs);
+
+        if (! dbus_connection_send (connection, reply, NULL))
+                g_error ("No memory");
+
+        dbus_message_unref (reply);
+
+        return DBUS_HANDLER_RESULT_HANDLED;
+}
+
 static DBusHandlerResult
 listener_dbus_filter_handle_methods (DBusConnection *connection,
                                      DBusMessage    *message, 
@@ -594,6 +661,9 @@ listener_dbus_filter_handle_methods (DBusConnection *connection,
         if (dbus_message_is_method_call (message, GS_LISTENER_SERVICE, "getIdle")) {
                 return listener_get_property (listener, connection, message, PROP_IDLE);
         }
+        if (dbus_message_is_method_call (message, GS_LISTENER_SERVICE, "getIdleTime")) {
+                return listener_get_idle_time (listener, connection, message);
+        }
         if (dbus_message_is_method_call (message, GS_LISTENER_SERVICE, "setThrottleEnabled")) {
                 return listener_set_property (listener, connection, message, PROP_THROTTLE_ENABLED);
         }
@@ -801,8 +871,8 @@ gs_listener_class_init (GSListenerClass *klass)
                               G_STRUCT_OFFSET (GSListenerClass, active_changed),
                               NULL,
                               NULL,
-                              g_cclosure_marshal_VOID__BOOLEAN,
-                              G_TYPE_NONE,
+                              gs_marshal_BOOLEAN__BOOLEAN,
+                              G_TYPE_BOOLEAN,
                               1,
                               G_TYPE_BOOLEAN);
         signals [THROTTLE_ENABLED_CHANGED] =
