@@ -35,9 +35,9 @@ static void gs_prefs_init       (GSPrefs      *prefs);
 static void gs_prefs_finalize   (GObject      *object);
 
 #define KEY_DIR            "/apps/gnome-screensaver"
-#define KEY_LOCK           KEY_DIR "/lock"
+#define KEY_LOCK_ENABLED   KEY_DIR "/lock_enabled"
 #define KEY_MODE           KEY_DIR "/mode"
-#define KEY_BLANK_DELAY    KEY_DIR "/blank_delay"
+#define KEY_ACTIVATE_DELAY KEY_DIR "/activate_delay"
 #define KEY_LOCK_DELAY     KEY_DIR "/lock_delay"
 #define KEY_CYCLE_DELAY    KEY_DIR "/cycle_delay"
 #define KEY_DPMS_ENABLED   KEY_DIR "/dpms_enabled"
@@ -45,9 +45,10 @@ static void gs_prefs_finalize   (GObject      *object);
 #define KEY_DPMS_SUSPEND   KEY_DIR "/dpms_suspend"
 #define KEY_DPMS_OFF       KEY_DIR "/dpms_off"
 #define KEY_THEMES         KEY_DIR "/themes"
-#define KEY_LOGOUT_ENABLED KEY_DIR "/logout_enabled"
 #define KEY_USER_SWITCH_ENABLED KEY_DIR "/user_switch_enabled"
+#define KEY_LOGOUT_ENABLED KEY_DIR "/logout_enabled"
 #define KEY_LOGOUT_DELAY   KEY_DIR "/logout_delay"
+#define KEY_LOGOUT_COMMAND KEY_DIR "/logout_command"
 
 #define GS_PREFS_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), GS_TYPE_PREFS, GSPrefsPrivate))
 
@@ -146,9 +147,9 @@ gs_prefs_load_from_gconf (GSPrefs *prefs)
         char *string;
         int   mode;
 
-        prefs->lock = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOCK, NULL);
+        prefs->lock_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOCK_ENABLED, NULL);
 
-        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_BLANK_DELAY, NULL);
+        value = gconf_client_get_int (prefs->priv->gconf_client, KEY_ACTIVATE_DELAY, NULL);
         if (value < 1)
                 value = 10;
         prefs->timeout = value * 60000;
@@ -198,11 +199,23 @@ gs_prefs_load_from_gconf (GSPrefs *prefs)
         /* Logout options */
 
         prefs->logout_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_LOGOUT_ENABLED, NULL);
+
+        string = gconf_client_get_string (prefs->priv->gconf_client, KEY_LOGOUT_COMMAND, NULL);
+        g_free (prefs->logout_command);
+        if (string) {
+                prefs->logout_command = g_strdup (string);
+        } else {
+                prefs->logout_command = NULL;
+        }
+        g_free (string);
+
         value = gconf_client_get_int (prefs->priv->gconf_client, KEY_LOGOUT_DELAY, NULL);
         if (value < 0)
                 value = 0;
         prefs->logout_timeout = value * 60000;
 
+        /* User switching options */
+
         prefs->user_switch_enabled = gconf_client_get_bool (prefs->priv->gconf_client, KEY_USER_SWITCH_ENABLED, NULL);
 }
 
@@ -268,7 +281,7 @@ key_changed_cb (GConfClient *client,
                                 g_free (s);
                         }
                 }
-        } else if (strcmp (key, KEY_BLANK_DELAY) == 0) {
+        } else if (strcmp (key, KEY_ACTIVATE_DELAY) == 0) {
                 int delay;
 
                 delay = gconf_value_get_int (value);
@@ -282,11 +295,11 @@ key_changed_cb (GConfClient *client,
                 delay = gconf_value_get_int (value);
                 prefs->lock_timeout = delay * 60000;
                 changed = TRUE;
-        } else if (strcmp (key, KEY_LOCK) == 0) {
+        } else if (strcmp (key, KEY_LOCK_ENABLED) == 0) {
                 gboolean enabled;
 
                 enabled = gconf_value_get_bool (value);
-                prefs->lock = enabled;
+                prefs->lock_enabled = enabled;
                 changed = TRUE;
         } else if (strcmp (key, KEY_CYCLE_DELAY) == 0) {
                 int delay;
@@ -334,9 +347,23 @@ key_changed_cb (GConfClient *client,
                 int delay;
 
                 delay = gconf_value_get_int (value);
-                if (delay < 1)
-                        delay = 1;
+                if (delay < 0)
+                        delay = 0;
                 prefs->logout_timeout = delay * 60000;
+                changed = TRUE;
+        } else if (strcmp (key, KEY_LOGOUT_COMMAND) == 0) {
+                const char *command;
+
+                command = gconf_value_get_string (value);
+
+                g_free (prefs->logout_command);
+
+                if (command) {
+                        prefs->logout_command = g_strdup (command);
+                } else {
+                        prefs->logout_command = NULL;
+                }
+
                 changed = TRUE;
         } else if (strcmp (key, KEY_USER_SWITCH_ENABLED) == 0) {
                 gboolean enabled;
@@ -360,34 +387,25 @@ gs_prefs_init (GSPrefs *prefs)
 
         prefs->priv->gconf_client      = gconf_client_get_default ();
 
-        prefs->use_sgi_saver_extension = FALSE;
-        prefs->use_mit_saver_extension = FALSE;
-        prefs->use_xidle_extension     = FALSE;
-        prefs->use_proc_interrupts     = FALSE;
-
-        prefs->pointer_timeout         = 5000;
-
-        prefs->lock                    = TRUE;
-
         prefs->verbose                 = FALSE;
         prefs->debug                   = FALSE;
 
-        prefs->timeout                 = 600000;
-        prefs->lock_timeout            = 0;
-        prefs->cycle                   = 600000;
-
+        prefs->lock_enabled            = TRUE;
+        prefs->logout_enabled          = FALSE;
+        prefs->user_switch_enabled     = FALSE;
         prefs->dpms_enabled            = TRUE;
         prefs->dpms_standby            = 7200000;
         prefs->dpms_suspend            = 7200000;
         prefs->dpms_off                = 14400000;
 
+        prefs->timeout                 = 600000;
+        prefs->lock_timeout            = 0;
+        prefs->logout_timeout          = 14400000;
+        prefs->cycle                   = 600000;
+
+
         prefs->mode                    = GS_MODE_SINGLE;
 
-        prefs->user_switch_enabled     = FALSE;
-
-        /* FIXME: for testing only */
-        prefs->themes = g_slist_append (prefs->themes, g_strdup ("popsquares"));
-
         /* GConf setup */
         gconf_client_add_dir (prefs->priv->gconf_client,
                               KEY_DIR,
@@ -424,6 +442,8 @@ gs_prefs_finalize (GObject *object)
                 g_slist_free (prefs->themes);
         }
 
+        g_free (prefs->logout_command);
+
         G_OBJECT_CLASS (parent_class)->finalize (object);
 }
 
